# Doodl

Doodl is the Swiss Army knife of data visualization. It has several audiences:

- Folks who want to write documents in Markdown that include high quality
  interactive (output format permitting) visualizations.

- Data analysts and data scientists who use any of the several Jupyter notebook
  derivative platforms to do data science.

- Web developers who would like to easily add charts and graphs to their Web
  apps in any of the major Web app platforms (work in progress).

- And soon, chatbot and other gen AI developers who would like their products
  to include high quality graphs and charts.

Under the hood, doodl is based on [d3](http://d3js.org), which means that
anything that you can do in d3, you can do in a PDF, Jupyter notebook, Web
app or a chatbot.

If you'd like to give it a spin, mosey on over to [doodl.ai](https://doodl.ai)
and click on "[Get started](https://doodl.ai/get-started.html)". You'll find
[extensive documentation](http://localhost:5173/docs.html) there as well.

Doodl is a project of [Hypericum](https://hypericum.ai), the computational
intuition company.
